@@ -808,7 +808,7 @@ SEXP dupVecR(SEXP x, SEXP uniq, SEXP fromLast) {
   if (isFactor(x) && buniq) {
     const int len = LENGTH(PROTECT(getAttrib(x, R_LevelsSymbol)));
     UNPROTECT(1);
-    bool *restrict count = (bool*)calloc(len,sizeof(bool));
+    bool *restrict count = (bool*)calloc(len+1,sizeof(bool));
     const int *restrict px = INTEGER(x);
     const int xlen = LENGTH(x);
     SEXP ans = PROTECT(allocVector(INTSXP, len));
